@@ -1,8 +1,8 @@
 use strict;
 use warnings;
 package Dist::Zilla::Plugin::VerifyPhases;
-# git description: v0.003-12-g943f305
-$Dist::Zilla::Plugin::VerifyPhases::VERSION = '0.004';
+# git description: v0.004-4-gc699ce3
+$Dist::Zilla::Plugin::VerifyPhases::VERSION = '0.005';
 # ABSTRACT: Compare data and files at different phases of the distribution build process
 # KEYWORDS: plugin distribution configuration phase verification validation
 # vim: set ts=8 sw=4 tw=78 et :
@@ -17,7 +17,7 @@ with
     'Dist::Zilla::Role::AfterBuild';
 use Moose::Util 'find_meta';
 use Digest::MD5 'md5_hex';
-use List::Util 1.33 qw(none first);
+use List::Util 1.33 qw(none first any);
 use namespace::autoclean;
 
 # filename => { object => $file_object, content => $checksummed_content }
@@ -33,6 +33,21 @@ has skip => (
     default => sub { [ qw(Makefile.PL Build.PL) ] },
 );
 
+my %zilla_constructor_args;
+
+sub BUILD
+{
+    my $self = shift;
+    my $zilla = $self->zilla;
+
+    # no phases have been run yet, so we can effectively capture the initial
+    # state of the zilla object (and determine its construction args)
+    %zilla_constructor_args = map {
+        my $attr = find_meta($zilla)->find_attribute_by_name($_);
+        $attr->has_value($zilla) ? ( $_ => $attr->get_value($zilla) ) : ()
+    } qw(name version abstract main_module authors distmeta _license_class _copyright_holder _copyright_year);
+}
+
 # nothing to put in dump_config yet...
 # around dump_config => sub { ... };
 
@@ -49,15 +64,24 @@ sub gather_files
 {
     my $self = shift;
 
-    foreach my $attr_name (qw(name version abstract main_module license authors distmeta))
+    my $zilla = $self->zilla;
+    foreach my $attr_name (qw(name version abstract main_module authors distmeta))
     {
-        my $attr = find_meta($self->zilla)->find_attribute_by_name($attr_name);
+        next if exists $zilla_constructor_args{$attr_name};
         $self->log($attr_name . ' has already been calculated by end of file gathering phase')
-            if $attr->has_value($self->zilla);
+            if find_meta($zilla)->find_attribute_by_name($attr_name)->has_value($zilla);
     }
 
+    # license is created from some private attrs, which may have been provided
+    # at construction time
+    $self->log('license has already been calculated by end of file gathering phase')
+        if any {
+            not exists $zilla_constructor_args{$_}
+                and find_meta($zilla)->find_attribute_by_name($_)->has_value($zilla)
+        } qw(_license_class _copyright_holder _copyright_year);
+
     # all files should have been added by now. save their filenames/objects
-    foreach my $file (@{$self->zilla->files})
+    foreach my $file (@{$zilla->files})
     {
         $all_files{$file->name} = {
             object => $file,
@@ -106,13 +130,13 @@ sub prune_files
         # file has been renamed - an odd time to do this
         if (my $orig_filename = first { $all_files{$_}{object} == $file } keys %all_files)
         {
-            $self->log('file has been renamed by end of file gathering phase: \'' . $file->name
+            $self->log('file has been renamed after file gathering phase: \'' . $file->name
                 . "' (originally '$orig_filename', " . $file->added_by . ')');
             delete $all_files{$orig_filename};
             next;
         }
 
-        $self->log('file has been added by end of file gathering phase: \'' . $file->name
+        $self->log('file has been added after file gathering phase: \'' . $file->name
             . '\' (' . $file->added_by . ')');
     }
 
@@ -157,14 +181,14 @@ sub munge_files
         }
 
         # this is a new file we haven't seen before.
-        $self->log('file has been added by end of file gathering phase: \'' . $file->name
+        $self->log('file has been added after file gathering phase: \'' . $file->name
             . '\' (' . $file->added_by . ')');
     }
 
     # now report on any files added earlier that were removed.
     foreach my $filename (keys %all_files)
     {
-        $self->log('file has been removed by end of file pruning phase: \'' . $filename
+        $self->log('file has been removed after file pruning phase: \'' . $filename
             . '\' (' . $all_files{$filename}{object}->added_by . ')');
     }
 
@@ -187,7 +211,7 @@ sub munge_files
     # verify that nothing has tried to read the prerequisite data yet
     # (not possible until the attribute stops being unlazily built)
     # my $prereq_attr = find_meta($self->zilla)->find_attribute_by_name('prereqs');
-    # $self->log('prereqs have already been read from by end of munging phase!')
+    # $self->log('prereqs have already been read from after munging phase!')
     #     if $prereq_attr->has_value($self->zilla);
 }
 
@@ -206,13 +230,13 @@ sub after_build
         {
             if (my $orig_filename = first { $all_files{$_}{object} == $file } keys %all_files)
             {
-                $self->log('file has been renamed by end of munging phase: \'' . $file->name
+                $self->log('file has been renamed after munging phase: \'' . $file->name
                     . "' (originally '$orig_filename', " . $file->added_by . ')');
                 delete $all_files{$orig_filename};
             }
             else
             {
-                $self->log('file has been added by end of file gathering phase: \'' . $file->name
+                $self->log('file has been added after file gathering phase: \'' . $file->name
                     . '\' (' . $file->added_by . ')');
             }
             next;
@@ -220,7 +244,7 @@ sub after_build
 
         # we give FromCode files a bye, since there is a good reason why their
         # content at file munging time is incomplete
-        $self->log('content has changed by end of munging phase: \'' . $file->name
+        $self->log('content has changed after munging phase: \'' . $file->name
             # this looks suspicious; we ought to have separate added_by,
             # changed_by attributes
                 . '\' (' . $file->added_by . ')')
@@ -233,7 +257,7 @@ sub after_build
 
     foreach my $filename (keys %all_files)
     {
-        $self->log('file has been removed by end of file pruning phase: \'' . $filename
+        $self->log('file has been removed after file pruning phase: \'' . $filename
             . '\' (' . $all_files{$filename}{object}->added_by . ')');
     }
 }
@@ -252,7 +276,7 @@ Dist::Zilla::Plugin::VerifyPhases - Compare data and files at different phases o
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -327,7 +351,7 @@ content, as interesting side effects can occur if their content subs are run
 before all content is available (for example, other lazy builders can run too
 early, resulting in incomplete or missing data).
 
-=for Pod::Coverage before_build gather_files set_file_encodings prune_files munge_files after_build
+=for Pod::Coverage BUILD before_build gather_files set_file_encodings prune_files munge_files after_build
 
 =head1 SUPPORT
 
